@@ -30,7 +30,7 @@ from __future__ import print_function
 '''
 Module for interacting with Nessus REST interface
 '''
-__version__ = "0.11"
+__version__ = "0.12"
 
 import os
 import sys
@@ -48,8 +48,6 @@ class Scanner(object):
     def __init__(self, url, login, password):
         self.name = ''
         self.policy_name = ''
-        self.creds_smb = []
-        self.creds_ssh = []
         self.debug = False
         self.format = ''
         self.format_start = ''
@@ -217,7 +215,7 @@ class Scanner(object):
         self.ver_plugins = self.res['loaded_plugin_set']
 
 ################################################################################
-    def policy_add(self, name, plugins, template="advanced"):
+    def policy_add(self, name, plugins, credentials, template="advanced"):
         '''
         Add a policy and store the returned ID. The template defaults to
         "advanced" to remain compatible with the calls that occur in Nessus
@@ -236,7 +234,7 @@ class Scanner(object):
             print("policy_id was not returned. Exiting")
             sys.exit(1)
 
-        self._policy_set_creds()
+        self.policy_add_creds(credentials=credentials)
         self._policy_set_settings()
         self._enable_plugins(plugins=plugins)
 
@@ -293,7 +291,7 @@ class Scanner(object):
         if not policy_id:
             policy_id = self.policy_id
 
-        creds = collections.defaultdict(lambda:collections.defaultdict(list))
+        creds = collections.defaultdict(lambda: collections.defaultdict(list))
 
         for credential in credentials:
             creds[credential.category][credential.name].append(credential.__dict__)
@@ -302,55 +300,12 @@ class Scanner(object):
         self.action(action="policies/" + str(policy_id),
                     method="put", extra=creds)
 
-################################################################################
-    def _policy_set_creds(self):
-        '''
-        Set credentials. This might need a helper function to build the lists
-        of credentials in an easier manner.
-        '''
-
-        smb = {"credentials": {"add": {"Host": {"Windows": []}}}}
-        ssh = {"credentials": {"add": {"Host": {"SSH": []}}}}
-
-        if self.creds_smb:
-            for login in self.creds_smb:
-                # consider the domain optional, and make it empty if not
-                # supplied
-                if "domain" not in login:
-                    login["domain"] = ""
-                if not login["username"]:
-                    continue
-
-                smb["credentials"]["add"]["Host"]["Windows"].append(
-                    {"username": login["username"],
-                     "password": login["password"],
-                     "domain": login["domain"],
-                     "auth_method": "Password"})
-
-        self.action(action="policies/" + str(self.policy_id),
-                    method="put", extra=smb)
-
-        if self.creds_ssh:
-            for login in self.creds_ssh:
-                # SSH elevation defaults to a standard login if "elevate" is not
-                # supplied
-                if "elevate" not in login:
-                    login["elevate"] = "Nothing"
-
-                ssh["credentials"]["add"]["Host"]["SSH"].append(
-                    {"username": login["username"],
-                     "password": login["password"],
-                     "elevate_privileges_with": login["elevate"],
-                     "auth_method": "password"})
-
-        self.action(action="policies/" + str(self.policy_id),
-                    method="put", extra=ssh)
-
 ################################################################################
     def _policy_set_settings(self):
         '''
         Current settings include: safe_checks, scan_webapps, report_paranoia,
-        provided_creds_only, thorough_tests, report_verbosity, silent_dependencies
+        provided_creds_only, thorough_tests, report_verbosity,
+        silent_dependencies
         '''
         settings = {"settings": {}}
 
@@ -607,7 +562,7 @@ class Scanner(object):
 
 ################################################################################
     def _deduplicate_hosts(self, hosts):
-        return list({v["hostname"]:v for v in hosts}.values())
+        return list({v["hostname"]: v for v in hosts}.values())
 
 ################################################################################
     def download_kbs(self):
@@ -620,10 +575,10 @@ class Scanner(object):
         kbs = {}
         for host in hosts:
             kbs[host["hostname"]] = self.action("scans/" + str(self.scan_id) +
-                                              "/hosts/" + str(host["host_id"]) +
-                                              "/kb?token=" + str(self.token),
-                                              method="get",
-                                              download=True)
+                                                "/hosts/" + str(host["host_id"]) +
+                                                "/kb?token=" + str(self.token),
+                                                method="get",
+                                                download=True)
 
         return kbs
 
@@ -686,16 +641,17 @@ class Scanner(object):
             if self.format_end:
                 print(self.format_end)
 
-        for host in self.res["comphosts"]:
-            print("----------------------------------------")
-            print("Target    : %s" % host["hostname"])
-            print("----------------------------------------\n")
+        if self.res is not None:
+            for host in self.res["comphosts"]:
+                print("----------------------------------------")
+                print("Target    : %s" % host["hostname"])
+                print("----------------------------------------\n")
 
-            for plugin in self.res["compliance"]:
-                self.action("scans/" + str(self.scan_id) + "/hosts/" +
-                            str(host["host_id"]) + "/compliance/" + str(plugin['plugin_id']),
-                            method="get")
-                self.pretty_print()
+                for plugin in self.res["compliance"]:
+                    self.action("scans/" + str(self.scan_id) + "/hosts/" +
+                                str(host["host_id"]) + "/compliance/" +
+                                str(plugin['plugin_id']), method="get")
+                    self.pretty_print()
 
 ################################################################################
     def upload(self, upload_file, file_contents=""):
@@ -724,7 +680,7 @@ class Scanner(object):
         data = {'file': filename}
         self.action(action="policies/import",
                     method="post",
-                    extra =data)
+                    extra=data)
         print("Imported policy named '%s', id %s" % (self.res['name'],
                                                      self.res['id']))
         return self.res['id']
